﻿
using System.IO;


class Program
{
   static void Main(string[] args)
   {
      //using (StreamWriter sw = new StreamWriter("test.txt"))
      using (StreamWriter sw = new StreamWriter(System.Console.OpenStandardOutput()))
      {
         try
         {
            // uncomment following block to search for bioPlux devices in range
            /*string[] devs = Bioplux.Device.FindDevices();
            foreach (string str in devs)
               sw.WriteLine(str);*/
            
            // Example without "using" keyword - need to call Dispose() at the end
            Bioplux.Device dev = new Bioplux.Device("00:07:80:79:6F:EF");  // replace with your device MAC address
            sw.WriteLine(dev.GetDescription());

            dev.BeginAcq(1000, 0xFF, 16); // start acquiring data at 1000 Hz, 8 channels, 16-bit resolution

            // initialize an array of 10 frames
            Bioplux.Device.Frame[] frames = new Bioplux.Device.Frame[10];
            for(int i = 0; i < frames.Length; i++)
               frames[i] = new Bioplux.Device.Frame();   // must initialize all elements in the array

            // receive and print out 10 data frames
            dev.GetFrames(10, frames);
            foreach (Bioplux.Device.Frame frame in frames)
            {
               sw.Write("Seq: {0}  Dig_in: {1}  An_in:", frame.seq, frame.dig_in);
               foreach (int val in frame.an_in)
                  sw.Write("\t{0}", val);
               sw.WriteLine();
            }

            dev.SetDOut(true);  // digital output is not used, this line can be removed
            dev.EndAcq();  // end acquisition
            dev.Dispose(); // disconnect from device

            // Example with "using" keyword - Dispose() is automatically called at the end, no need to call it explicitly
            using (Bioplux.Device d = new Bioplux.Device("00:07:80:79:6F:EF"))  // replace with your device MAC address
            {
               sw.WriteLine(d.GetDescription());
            }
         }
         catch(Bioplux.BPException e)
         {
            sw.WriteLine("bioPlux exception: {0}", e.Message);
         }
      }
   }
}
